@@ -11,7 +11,7 @@ from molSimplify.Classes.globalvars import globalvars
 
 class atom3D:
     """ atom3D class. Base class in molSimplify for representing an element.
-        
+
         Parameters
         ----------
             Sym : str, optional
@@ -23,8 +23,8 @@ class atom3D:
             partialcharge : int, optional
                 Charge assigned to atom when added to mol. Default is None.
     """
-    def __init__(self, Sym='C', xyz=[0.0, 0.0, 0.0], name=False, partialcharge=None, Tfactor=0, greek='', occup=1.00, loc=''):
-       
+    def __init__(self, Sym='C', xyz=None, name=False, partialcharge=None, Tfactor=0, greek='', occup=1.00, loc=''):
+
         # Element symbol
         self.sym = Sym
         self.partialcharge = None
@@ -53,17 +53,19 @@ class atom3D:
         self.metal = None
 
         # Coordinates
+        if xyz is None:
+            xyz = [0.0, 0.0, 0.0]
         self.__xyz = xyz
-        
+
         # Temperature factor (only useful for proteins)
         self.Tfactor = Tfactor
-        
+
         # Greek letter (e.g. alpha carbon - only useful for proteins)
-        if greek == '': 
+        if greek == '':
             self.greek = Sym
         else:
             self.greek = greek
-        
+
         # Occupancy (only useful for proteins)
         self.occup = occup
 
@@ -75,7 +77,7 @@ class atom3D:
 
     def __repr__(self):
         """Returns all bound methods of the mol3D class..
-        
+
         Returns
         -------
             method_string : string
@@ -90,7 +92,7 @@ class atom3D:
 
     def coords(self):
         """ Get coordinates of a given atom.
-        
+
         Returns
         -------
             coords : list
@@ -101,13 +103,13 @@ class atom3D:
 
     def distance(self, atom2):
         """ Get distance from one atom3D class to another.
-        
+
         Parameters
         ----------
             atom2 : atom3D
                 atom3D class of the atom to measure distance from.
 
-        
+
         Returns
         -------
             dist : float
@@ -122,13 +124,13 @@ class atom3D:
 
     def distancev(self, atom2):
         """ Get distance vector from one atom3D class to another.
-        
+
         Parameters
         ----------
             atom2 : atom3D
                 atom3D class of the atom to measure distance from.
 
-        
+
         Returns
         -------
             dist_list : list
@@ -141,14 +143,14 @@ class atom3D:
         dz = xyz[2]-point[2]
         return [dx, dy, dz]
 
-    def ismetal(self, transition_metals_only=True):
+    def ismetal(self, transition_metals_only: bool = True) -> bool:
         """ Identify whether an atom is a metal.
 
         Parameters
         ----------
             transition_metals_only : bool, optional
                 Identify only transition metals. Default is true.
-        
+
         Returns
         -------
             metal : bool
@@ -163,7 +165,7 @@ class atom3D:
 
     def setcoords(self, xyz):
         """ Set coordinates of an atom3D class to a new location.
-        
+
         Parameters
         ----------
             xyz : list
@@ -175,7 +177,7 @@ class atom3D:
 
     def symbol(self):
         """ Return symbol of atom3D.
-        
+
         Returns
         -------
             symbol : str
@@ -210,7 +212,7 @@ class atom3D:
         Parameters
         ----------
             dxyz : list
-                Displacement vector of length 3: [dx, dy, dz]. 
+                Displacement vector of length 3: [dx, dy, dz].
 
         """
         x, y, z = self.__xyz
