@@ -1,5 +1,5 @@
 from molSimplify.Scripts.cellbuilder_tools import *
-from molSimplify.Classes import mol3D
+from molSimplify.Classes.mol3D import mol3D
 from molSimplify.Informatics.autocorrelation import*
 from molSimplify.Informatics.misc_descriptors import*
 from molSimplify.Informatics.graph_analyze import*
@@ -11,8 +11,9 @@ from scipy.spatial import distance
 from scipy import sparse
 import itertools
 from molSimplify.Informatics.MOF.PBC_functions import *
+import re
 
-#### NOTE: In addition to molSimplify's dependencies, this portion requires 
+#### NOTE: In addition to molSimplify's dependencies, this portion requires
 #### pymatgen to be installed. The RACs are intended to be computed
 #### on the primitive cell of the material. You can compute them
 #### using the commented out snippet of code if necessary.
@@ -51,7 +52,7 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
     descriptors = []
     if sbupath:
         sbu_descriptor_path = os.path.dirname(sbupath)
-        if os.path.getsize(sbu_descriptor_path+'/sbu_descriptors.csv')>0:            
+        if os.path.getsize(sbu_descriptor_path+'/sbu_descriptors.csv')>0:
             sbu_descriptors = pd.read_csv(sbu_descriptor_path+'/sbu_descriptors.csv')
         else:
             sbu_descriptors = pd.DataFrame()
@@ -70,7 +71,7 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
         for val in SBU:
             SBU_mol.addAtom(molcif.getAtom(val))
         SBU_mol.graph = SBU_subgraph[i].todense()
-        
+
         """""""""
         For each linker connected to the SBU, find the lc atoms for the lc-RACs.
         """""""""
@@ -98,7 +99,7 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
                 descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],results_dictionary['results'],'D_lc','all')
                 # print('2',len(descriptor_names),len(descriptors))
                 """""""""
-                If heteroatom functional groups exist (anything that is not C or H, so methyl is missed, also excludes anything lc, so carboxylic metal-coordinating oxygens skipped), 
+                If heteroatom functional groups exist (anything that is not C or H, so methyl is missed, also excludes anything lc, so carboxylic metal-coordinating oxygens skipped),
                 compile the list of atoms
                 """""""""
                 functional_atoms = []
@@ -106,7 +107,7 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
                     if not jj in link_list:
                         if not set({temp_mol.atoms[jj].sym}) & set({"C","H"}):
                             functional_atoms.append(jj)
-            
+
                 if len(functional_atoms) > 0:
                     results_dictionary = generate_atomonly_autocorrelations(temp_mol, functional_atoms , loud=False, depth=depth, oct=False, polarizability=True)
                     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,results_dictionary['colnames'],results_dictionary['results'],'func','all')
@@ -225,7 +226,7 @@ def make_MOF_linker_RACs(linkerlist, linker_subgraphlist, molcif, depth, name, c
     return colnames, averaged_ligand_descriptors
 
 
-def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
+def get_MOF_descriptors(data, depth, path=False, xyzpath = False, graph_provided = False):
     if not path:
         print('Need a directory to place all of the linker, SBU, and ligand objects. Exiting now.')
         raise ValueError('Base path must be specified in order to write descriptors.')
@@ -260,7 +261,6 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     Input cif file and get the cell parameters and adjacency matrix. If overlap, do not featurize.
     Simultaneously prepare mol3D class for MOF for future RAC featurization (molcif)
     """""""""
-
     cpar, allatomtypes, fcoords = readcif(data)
     cell_v = mkcell(cpar)
     cart_coords = fractional2cart(fcoords,cell_v)
@@ -272,20 +272,42 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
         tmpstr = "Failed to featurize %s: large primitive cell\n"%(name)
         write2file(path,"/FailedStructures.log",tmpstr)
         return full_names, full_descriptors
-    distance_mat = compute_distance_matrix3(cell_v,cart_coords)
-    try:
-        adj_matrix=compute_adj_matrix(distance_mat,allatomtypes)
-    except NotImplementedError:
-        full_names = [0]
-        full_descriptors = [0]
-        tmpstr = "Failed to featurize %s: atomic overlap\n"%(name)
-        write2file(path,"/FailedStructures.log",tmpstr)
-        return full_names, full_descriptors
-
+    if not graph_provided:
+        distance_mat = compute_distance_matrix3(cell_v,cart_coords)
+        try:
+            adj_matrix=compute_adj_matrix(distance_mat,allatomtypes)
+        except NotImplementedError:
+            full_names = [0]
+            full_descriptors = [0]
+            tmpstr = "Failed to featurize %s: atomic overlap\n"%(name)
+            write2file(path,"/FailedStructures.log",tmpstr)
+            return full_names, full_descriptors
+    else:
+        adj_matrix_list = []
+        max_sofar = 0
+        with open(data.replace('primitive','cif'),'r') as f:
+            readdata = f.readlines()
+            flag = False
+            for i, row in enumerate(readdata):
+                if '_ccdc_geom_bond_type' in row:
+                    flag = True
+                    continue
+                if flag:
+                    splitrow = row.split()
+                    atom1 = int(re.findall(r'\d+',splitrow[0])[0])
+                    atom2 = int(re.findall(r'\d+',splitrow[1])[0])
+                    max_sofar = max(atom1, max_sofar)
+                    max_sofar = max(atom2, max_sofar)
+                    adj_matrix_list.append((atom1,atom2))
+        adj_matrix = np.zeros((max_sofar+1,max_sofar+1))
+        for i, row in enumerate(adj_matrix_list):
+            adj_matrix[row[0],row[1]] = 1
+            adj_matrix[row[1],row[0]] = 1
+    adj_matrix = sparse.csr_matrix(adj_matrix)
     writeXYZandGraph(xyzpath, allatomtypes, cell_v, fcoords, adj_matrix.todense())
     molcif,_,_,_,_ = import_from_cif(data, True)
     molcif.graph = adj_matrix.todense()
-    
+
     """""""""
     check number of connected components.
     if more than 1: it checks if the structure is interpenetrated. Fails if no metal in one of the connected components (identified by the graph).
@@ -324,7 +346,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     removelist = set()
     Logs the atom types of the connecting atoms to the metal in logpath.
     """""""""
-    SBUlist = set() 
+    SBUlist = set()
     metal_list = set([at for at in molcif.findMetal(transition_metals_only=False)])
     # print('##### METAL LIST2', metal_list, [molcif.getAtom(val).symbol() for val in list(metal_list)])
     # print('##### all LIST2', metal_list, [val.symbol() for val in molcif.atoms])
@@ -339,25 +361,25 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
         cn_atom = ",".join([at for at in bonded_atoms_types])
         tmpstr = "atom %i with type of %s found to have %i coordinates with atom types of %s\n"%(metal,allatomtypes[metal],cn,cn_atom)
         write2file(logpath,"/%s.log"%name,tmpstr)
-    [removelist.update(set([atom])) for atom in SBUlist if all((molcif.getAtom(val).ismetal() or molcif.getAtom(val).symbol().upper() == 'H') for val in molcif.getBondedAtomsSmart(atom))] 
+    [removelist.update(set([atom])) for atom in SBUlist if all((molcif.getAtom(val).ismetal() or molcif.getAtom(val).symbol().upper() == 'H') for val in molcif.getBondedAtomsSmart(atom))]
     """""""""
     adding hydrogens connected to atoms which are only connected to metals. In particular interstitial OH, like in UiO SBU.
     """""""""
     for atom in SBUlist:
         for val in molcif.getBondedAtomsSmart(atom):
             if molcif.getAtom(val).symbol().upper() == 'H':
-               removelist.update(set([val])) 
+               removelist.update(set([val]))
 
     """""""""
     At this point:
-    The remove list only removes metals and things ONLY connected to metals or hydrogens. 
-    Thus the coordinating atoms are double counted in the linker.                         
-    
+    The remove list only removes metals and things ONLY connected to metals or hydrogens.
+    Thus the coordinating atoms are double counted in the linker.
+
     step 2: organic part
-        removelist = linkers are all atoms - the removelist (assuming no bond between 
+        removelist = linkers are all atoms - the removelist (assuming no bond between
         organiclinkers)
     """""""""
-    allatoms = set(range(0, adj_matrix.shape[0])) 
+    allatoms = set(range(0, adj_matrix.shape[0]))
     linkers = allatoms - removelist
     linker_list, linker_subgraphlist = get_closed_subgraph(linkers.copy(), removelist.copy(), adj_matrix)
     connections_list = copy.deepcopy(linker_list)
@@ -370,7 +392,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     anc_atoms = set()
     for linker in linker_list:
         for atom_linker in linker:
-            bonded2atom = np.nonzero(adj_matrix[atom_linker,:])[1] 
+            bonded2atom = np.nonzero(adj_matrix[atom_linker,:])[1]
             if set(bonded2atom) & metal_list:
                 anc_atoms.add(atom_linker)
     """""""""
@@ -388,17 +410,17 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     long_ligands = False
     max_min_linker_length , min_max_linker_length = (0,100)
     for ii, atoms_list in reversed(list(enumerate(linker_list))): #Loop over all linker subgraphs
-        linkeranchors_list = set() 
-        linkeranchors_atoms = set() 
-        sbuanchors_list = set() 
+        linkeranchors_list = set()
+        linkeranchors_atoms = set()
+        sbuanchors_list = set()
         sbu_connect_list = set()
         """""""""
-        Here, we are trying to identify what is actually a linker and what is a ligand. 
-        To do this, we check if something is connected to more than one SBU. Set to     
-        handle cases where primitive cell is small, ambiguous cases are recorded.       
+        Here, we are trying to identify what is actually a linker and what is a ligand.
+        To do this, we check if something is connected to more than one SBU. Set to
+        handle cases where primitive cell is small, ambiguous cases are recorded.
         """""""""
         for iii,atoms in enumerate(atoms_list): #loop over all atoms in a linker
-            connected_atoms = np.nonzero(adj_matrix[atoms,:])[1] 
+            connected_atoms = np.nonzero(adj_matrix[atoms,:])[1]
             for kk, sbu_atoms_list in enumerate(initial_SBU_list): #loop over all SBU subgraphs
                 for sbu_atoms in sbu_atoms_list: #Loop over SBU
                     if sbu_atoms in connected_atoms:
@@ -406,14 +428,14 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
                         linkeranchors_atoms.add(atoms)
                         sbuanchors_list.add(sbu_atoms)
                         sbu_connect_list.add(kk) #Add if unique SBUs
-        min_length,max_length = linker_length(linker_subgraphlist[ii].todense(),linkeranchors_list) 
+        min_length,max_length = linker_length(linker_subgraphlist[ii].todense(),linkeranchors_list)
 
         if len(linkeranchors_list) >=2 : # linker, and in one ambigous case, could be a ligand.
             if len(sbu_connect_list) >= 2: #Something that connects two SBUs is certain to be a linker
                 max_min_linker_length = max(min_length,max_min_linker_length)
                 min_max_linker_length = min(max_length,min_max_linker_length)
                 continue
-            else: 
+            else:
                 # check number of times we cross PBC :
                 # TODO: we still can fail in multidentate ligands!
                 linker_cart_coords = np.array([
@@ -425,16 +447,16 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
                 sbu_temp = list(sbu_temp)
                 sbu_cart_coords = np.array([
                     at.coords() for at in [molcif.getAtom(val) for val in sbu_temp]])
-                sbu_adjmat = slice_mat(adj_matrix.todense(),sbu_temp) 
+                sbu_adjmat = slice_mat(adj_matrix.todense(),sbu_temp)
                 pr_image_sbu = ligand_detect(cell_v,sbu_cart_coords,sbu_adjmat,set(range(len(linkeranchors_list))))
-                if not (len(np.unique(pr_image_sbu, axis=0))==1 and len(np.unique(pr_image_organic, axis=0))==1): # linker 
+                if not (len(np.unique(pr_image_sbu, axis=0))==1 and len(np.unique(pr_image_organic, axis=0))==1): # linker
                     max_min_linker_length = max(min_length,max_min_linker_length)
                     min_max_linker_length = min(max_length,min_max_linker_length)
                     tmpstr = str(name)+','+' Anchors list: '+str(sbuanchors_list) \
                             +','+' SBU connectlist: '+str(sbu_connect_list)+' set to be linker\n'
                     write2file(ligandpath,"/ambiguous.txt",tmpstr)
                     continue
-                else: #  all anchoring atoms are in the same unitcell -> ligand 
+                else: #  all anchoring atoms are in the same unitcell -> ligand
                     removelist.update(set(templist[ii])) # we also want to remove these ligands
                     SBUlist.update(set(templist[ii])) # we also want to remove these ligands
                     linker_list.pop(ii)
@@ -458,7 +480,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
     tmpstr = str(name) + ", (min_max_linker_length,max_min_linker_length): " + \
                 str(min_max_linker_length) + " , " +str(max_min_linker_length) + "\n"
     write2file(logpath,"/%s.log"%name,tmpstr)
-    if min_max_linker_length < 3: 
+    if min_max_linker_length < 3:
         write2file(linkerpath,"/short_ligands.txt",tmpstr)
     if min_max_linker_length > 2:
         # for N-C-C-N ligand ligand
@@ -466,7 +488,7 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
             long_ligands = True
         elif min_max_linker_length > 3:
             long_ligands = True
-    
+
     """""""""
     In the case of long linkers, add second coordination shell without further checks. In the case of short linkers, start from metal
     and grow outwards using the include_extra_shells function
@@ -484,13 +506,13 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
         if not long_ligands:
             tmpstr = "\nStructure has SHORT ligand\n\n"
             write2file(logpath,"/%s.log"%name,tmpstr)
-            SBU_list , SBU_subgraphlist = include_extra_shells(SBU_list,SBU_subgraphlist,molcif ,adj_matrix) 
+            SBU_list , SBU_subgraphlist = include_extra_shells(SBU_list,SBU_subgraphlist,molcif ,adj_matrix)
     else:
         tmpstr = "Structure %s has extreamly short ligands, check the outputs\n"%name
         write2file(ligandpath,"/ambiguous.txt",tmpstr)
-        tmpstr = "Structure has extreamly short ligands\n" 
+        tmpstr = "Structure has extreamly short ligands\n"
         write2file(logpath,"/%s.log"%name,tmpstr)
-        tmpstr = "Structure has extreamly short ligands\n" 
+        tmpstr = "Structure has extreamly short ligands\n"
         write2file(logpath,"/%s.log"%name,tmpstr)
         truncated_linkers = allatoms - removelist
         SBU_list, SBU_subgraphlist = get_closed_subgraph(removelist, truncated_linkers, adj_matrix)
@@ -539,5 +561,5 @@ def get_MOF_descriptors(data, depth, path=False, xyzpath = False):
 #     full_descriptors.append(cif_file)
 #     featurization = dict(zip(full_names, full_descriptors))
 #     featurization_list.append(featurization)
-# df = pd.DataFrame(featurization_list) 
-# df.to_csv('./full_featurization_frame.csv',index=False) 
+# df = pd.DataFrame(featurization_list)
+# df.to_csv('./full_featurization_frame.csv',index=False)
