@@ -7,14 +7,27 @@
 ########     RACs from lists of ligands    ###############
 ##########################################################
 from __future__ import print_function
-import numpy as np
+
 import sys
 
-from molSimplify.Classes import mol3D
-from molSimplify.Informatics.autocorrelation import*
-from molSimplify.Informatics.misc_descriptors import*
-from molSimplify.Informatics.graph_analyze import*
-from molSimplify.Informatics.rac155_geo import*
+from molSimplify.Classes.mol3D import mol3D
+from molSimplify.Informatics.autocorrelation import (generate_all_ligand_autocorrelation_derivatives,
+                                                     generate_all_ligand_autocorrelations,
+                                                     generate_all_ligand_deltametric_derivatives,
+                                                     generate_all_ligand_deltametrics,
+                                                     generate_full_complex_autocorrelation_derivatives,
+                                                     generate_full_complex_autocorrelations,
+                                                     generate_metal_autocorrelation_derivatives,
+                                                     generate_metal_autocorrelations,
+                                                     generate_metal_deltametric_derivatives,
+                                                     generate_metal_deltametrics,
+                                                     generate_metal_ox_autocorrelation_derivatives,
+                                                     generate_metal_ox_autocorrelations,
+                                                     generate_metal_ox_deltametric_derivatives,
+                                                     generate_metal_ox_deltametrics)
+from molSimplify.Informatics.misc_descriptors import (generate_all_ligand_misc)
+from molSimplify.Informatics.rac155_geo import (rac155_list)
+import numpy as np
 
 ## Gets the connectivity matrix of an octahedral complex without geo
 #  @param metal_mol mol3D() for the metal
@@ -73,7 +86,7 @@ def assemble_connectivity_from_parts(metal_mol, custom_ligand_dict):
 #  @param custom_ligand_dict optional dict defining ligands (see below)
 #  @return descriptor_names updated names
 #  @return descriptors updated RACs
-def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=False, NumB=False, Zeff=False):
+def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=False, NumB=False, Gval=False):
     descriptor_names = []
     descriptors = []
     ## misc descriptors
@@ -86,7 +99,7 @@ def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=Fals
 
     ## full ACs
     results_dictionary = generate_full_complex_autocorrelations(this_complex,depth=3,loud=False,flag_name=False,
-                                                                modifier=ox_modifier, NumB=NumB, Zeff=Zeff)
+                                                                modifier=ox_modifier, NumB=NumB, Gval=Gval)
     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,
                                                         results_dictionary['colnames'],results_dictionary['results'],'f','all')
 
@@ -95,7 +108,7 @@ def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=Fals
     results_dictionary = generate_all_ligand_autocorrelations(this_complex,depth=3,loud=False,name=False,
                                                                 flag_name=False,
                                                                 custom_ligand_dict=custom_ligand_dict,
-                                                                NumB=NumB, Zeff=Zeff)
+                                                                NumB=NumB, Gval=Gval)
     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,
                                                         results_dictionary['colnames'],results_dictionary['result_ax_full'],'f','ax')
     descriptor_names, descriptors =  append_descriptors(descriptor_names, descriptors,
@@ -107,7 +120,7 @@ def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=Fals
 
     results_dictionary = generate_all_ligand_deltametrics(this_complex,depth=3,loud=False,name=False,
                                                             custom_ligand_dict=custom_ligand_dict,
-                                                            NumB=NumB, Zeff=Zeff)
+                                                            NumB=NumB, Gval=Gval)
     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,
                                                         results_dictionary['colnames'],results_dictionary['result_ax_con'],'D_lc','ax')
     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,
@@ -117,13 +130,13 @@ def get_descriptor_vector(this_complex,custom_ligand_dict=False,ox_modifier=Fals
     #print('getting metal ACs')
     results_dictionary = generate_metal_autocorrelations(this_complex,depth=3,loud=False,
                                                             modifier=ox_modifier,
-                                                            NumB=NumB,Zeff=Zeff)
+                                                            NumB=NumB,Gval=Gval)
     descriptor_names, descriptors =  append_descriptors(descriptor_names, descriptors,
                                                         results_dictionary['colnames'],results_dictionary['results'],'mc','all')
 
     results_dictionary = generate_metal_deltametrics(this_complex,depth=3,loud=False,
                                                         modifier=ox_modifier,
-                                                        NumB=NumB,Zeff=Zeff)
+                                                        NumB=NumB,Gval=Gval)
     descriptor_names, descriptors = append_descriptors(descriptor_names, descriptors,
                                                         results_dictionary['colnames'],results_dictionary['results'],'D_mc','all')
 
@@ -232,8 +245,8 @@ def get_descriptor_derivatives(this_complex,custom_ligand_dict=False,ox_modifier
 def create_OHE(descriptor_names,descriptors, metal,oxidation_state):
     # fucntion to append OHE encoding of oxidation state
     # and d-electron countst
-    OHE_names = ['ox2','ox3','d3','d4','d5','d6','d7','d8']
-    OHE_values = [   0,    0,   0,   0,   0,   0,    0, 0]
+    OHE_names = ['ox2', 'ox3', 'd3', 'd4', 'd5', 'd6', 'd7', 'd8']
+    OHE_values = [0] * len(OHE_names)
     #print(OHE_values)
     if int(oxidation_state) == 2:
         OHE_values[0]+=1
@@ -321,27 +334,3 @@ def append_descriptor_derivatives(descriptor_derivative_names,descriptor_derivat
     else:
         descriptor_derivatives =  np.row_stack([descriptor_derivatives,dmat])
     return descriptor_derivative_names, descriptor_derivatives
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
