@@ -53,6 +53,16 @@ def get_descriptor_vector(this_complex, custom_ligand_dict=False,
             index of the metal atom to generate property, by default False
         smiles_charge : bool, optional
             use obmol conversion through smiles to assign ligand_misc_charges, by default False
+        use_dist : bool, optional
+            Whether or not CD-RACs used.
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        alleq : bool, optional
+            Whether or not all ligands are equatorial.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
+        depth : int, optional
+            The depth of the RACs (how many bonds out the RACs go).
 
     Returns
     -------
@@ -150,8 +160,8 @@ def get_descriptor_vector(this_complex, custom_ligand_dict=False,
     return descriptor_names, descriptors
 
 
-def get_descriptor_derivatives(this_complex, custom_ligand_dict=False, ox_modifier=False, lacRACs=True, loud=False,
-                                metal_ind=None):
+def get_descriptor_derivatives(this_complex, custom_ligand_dict=False, ox_modifier=False,
+                               lacRACs=True, depth=4, loud=False, metal_ind=None):
     """ Calculate and return all derivatives of RACs for a given octahedral complex.
 
     Parameters
@@ -173,6 +183,8 @@ def get_descriptor_derivatives(this_complex, custom_ligand_dict=False, ox_modifi
         lacRACs : bool, optional
             Use ligand_assign_consistent (lac) to represent mol3D given
             if False, use ligand_assign (older), default True
+        depth : int, optional
+            depth of RACs to calculate, by default 4
         loud : bool, optional
             Print debugging information, by default False
         metal_ind : bool, optional
@@ -348,6 +360,8 @@ def autocorrelation(mol, prop_vec, orig, d, oct=True, use_dist=False, size_norma
             Flag is octahedral complex, by default True
         use_dist : bool, optional
             Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
 
     Returns
     -------
@@ -455,6 +469,10 @@ def deltametric(mol, prop_vec, orig, d, oct=True, use_dist=False, size_normalize
             number of hops to travel
         oct : bool, optional
             Flag is octahedral complex, by default True
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
 
     Returns
     -------
@@ -561,6 +579,8 @@ def construct_property_vector(mol, prop, oct=True, modifier=False, MRdiag_dict={
             if passed - dict, used to modify prop vector (e.g. for adding
             ONLY used with  ox_nuclear_charge    ox or charge)
             {"Fe":2, "Co": 3} etc, by default False
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -691,6 +711,10 @@ def full_autocorrelation(mol, prop, d, oct=True, modifier=False, use_dist=False,
             Use ox modifier, by default False
         use_dist : bool, optional
             Weigh autocorrelation by distance of atoms from each other, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -720,6 +744,8 @@ def full_autocorrelation_derivative(mol, prop, d, oct=True, modifier=False):
             depth of scope to evalue
         oct : bool, optional
             Is octahedral flag, by default True
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False            
         modifier : bool, optional
             Use ox modifier, by default False
 
@@ -761,12 +787,16 @@ def generate_full_complex_autocorrelations(mol, loud,
             Use ox_modifier on metal charge, by default False
         use_dist : bool, optional
             Weigh autocorrelations by interatomic distances, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.        
         NumB : bool, optional
             use number of bonds as RAC, by default False
         Gval : bool, optional
             use G value as RAC, by default False
         polarizability : bool, optional
             Use polarizability (alpha) as RAC, by default False
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -880,6 +910,12 @@ def atom_only_autocorrelation(mol, prop, d, atomIdx, oct=True, use_dist=False, s
             atoms from which the autocorrelation vector should be centered
         oct : bool, optional
             use octahedral flag, by default True
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -947,12 +983,18 @@ def metal_only_autocorrelation(mol, prop, d, oct=True, metal_ind=None,
             depth of autocorrelation
         oct : bool, optional
             use octahedral geometry evaluations, by default True
+        metal_ind : bool, optional
+            index of the metal atom to generate property, by default False
         func : function, optional
             which function to evaluate mc-racs by, by default autocorrelation
         modifier : bool, optional
             use ox_modifier, by default False
-        metal_ind : bool, optional
-            index of the metal atom to generate property, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.            
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -987,12 +1029,12 @@ def metal_only_autocorrelation_derivative(mol, prop, d, oct=True, metal_ind=None
             depth of autocorrelation
         oct : bool, optional
             use octahedral geometry evaluations, by default True
+        metal_ind : bool, optional
+            index (int) of metal atom to consider, default False
         func : function, optional
             which function to evaluate mc-racs by, by default autocorrelation_derivative
         modifier : bool, optional
             use ox_modifier, by default False
-        metal_ind : bool, optional
-            index (int) of metal atom to consider, default False
 
     Returns
     -------
@@ -1028,6 +1070,13 @@ def atom_only_deltametric(mol, prop, d, atomIdx, oct=True, modifier=False, use_d
             atoms from which the autocorrelation vector should be centered
         oct : bool, optional
             use octahedral flag, by default True
+        modifier : TODO
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -1098,12 +1147,12 @@ def metal_only_deltametric_derivative(mol, prop, d, oct=True, metal_ind=None,
             depth of autocorrelation
         oct : bool, optional
             use octahedral geometry evaluations, by default True
+        metal_ind : bool, optional
+            index of metal atom to consider, by default False
         func : function, optional
             which function to evaluate mc-racs by, by default deltametric_derivative
         modifier : bool, optional
             use ox_modifier, by default False
-        metal_ind : bool, optional
-            index of metal atom to consider, by default False
 
     Returns
     -------
@@ -1137,12 +1186,18 @@ def metal_only_deltametric(mol, prop, d, oct=True, metal_ind=None,
             depth of autocorrelation
         oct : bool, optional
             use octahedral geometry evaluations, by default True
+        metal_ind : bool, optional
+            index of metal atom to consider, by default False
         func : function, optional
             which function to evaluate mc-racs by, by default deltametric
         modifier : bool, optional
             use ox_modifier, by default False
-        metal_ind : bool, optional
-            index of metal atom to consider, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -1286,6 +1341,12 @@ def generate_all_ligand_autocorrelations(mol, loud, depth=4, flag_name=False,
             Use number of bonds as descriptor property, by default False
         Gval : bool, optional
             Use G value as descriptor property, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -1522,6 +1583,12 @@ def generate_all_ligand_deltametrics(mol, loud, depth=4, flag_name=False,
             Use number of bonds as descriptor property, by default False
         Gval : bool, optional
             Use G value as descriptor property, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -1707,6 +1774,12 @@ def generate_metal_autocorrelations(mol, loud, depth=4, oct=True, flag_name=Fals
             Use G value as descriptor property, by default False
         metal_ind : bool, optional
             index of the metal atom to generate property, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
@@ -1830,6 +1903,12 @@ def generate_metal_deltametrics(mol, loud, depth=4, oct=True, flag_name=False,
             Use G value as descriptor property, by default False
         metal_ind : bool, optional
             index of the metal atom to generate property, by default False
+        use_dist : bool, optional
+            Weigh autocorrelation by physical distance of atom from original, by default False
+        size_normalize : bool, optional
+            Whether or not to normalize by the number of atoms.
+        MRdiag_dict : dict, optional
+            Keys are ligand identifiers, values are MR diagnostics like E_corr.
 
     Returns
     -------
