@@ -1,20 +1,8 @@
-import glob
-import string
-import sys
-import os
-import numpy as np
-import math
-import random
-import string
-import numpy
-from molSimplify.Scripts.geometry import *
-#from molSimplify.Scripts.nn_prep import *
-from molSimplify.Classes.atom3D import *
-from molSimplify.Classes.globalvars import globalvars
-from molSimplify.Classes.mol3D import*
-from molSimplify.Classes.ligand import *
 from molSimplify.Classes.ligand import ligand_breakdown, ligand_assign
-from molSimplify.Informatics.graph_analyze import *
+from molSimplify.Informatics.graph_analyze import (get_lig_EN,
+                                                   get_truncated_kier,
+                                                   kier)
+import numpy as np
 
 
 def generate_all_ligand_misc(mol, loud, custom_ligand_dict=False, force_legacy=False):
@@ -175,15 +163,7 @@ def generate_all_ligand_misc_dimers(mol, loud, custom_ligand_dict=False):
     for ax_ligand_list, ax_con_int_list, n_ax, result_ax in zip(axligs, axcons, n_axs, result_axs):
         for i in range(0, n_ax):
             ax_ligand_list[i].mol.convert2OBMol()
-            if not (i == 0):
-                result_ax_dent += ax_ligand_list[i].dent
-                result_ax_maxdelen += get_lig_EN(
-                    ax_ligand_list[i].mol, ax_con_int_list[i])
-                result_ax_ki += kier(ax_ligand_list[i].mol)
-                result_ax_tki += get_truncated_kier(
-                    ax_ligand_list[i].mol, ax_con_int_list[i])
-                result_ax_charge += ax_ligand_list[i].mol.OBMol.GetTotalCharge()
-            else:
+            if i == 0:
                 result_ax_dent = ax_ligand_list[i].dent
                 result_ax_maxdelen = get_lig_EN(
                     ax_ligand_list[i].mol, ax_con_int_list[i])
@@ -191,6 +171,14 @@ def generate_all_ligand_misc_dimers(mol, loud, custom_ligand_dict=False):
                 result_ax_tki = get_truncated_kier(
                     ax_ligand_list[i].mol, ax_con_int_list[i])
                 result_ax_charge = ax_ligand_list[i].mol.OBMol.GetTotalCharge()
+            else:
+                result_ax_dent += ax_ligand_list[i].dent
+                result_ax_maxdelen += get_lig_EN(
+                    ax_ligand_list[i].mol, ax_con_int_list[i])
+                result_ax_ki += kier(ax_ligand_list[i].mol)
+                result_ax_tki += get_truncated_kier(
+                    ax_ligand_list[i].mol, ax_con_int_list[i])
+                result_ax_charge += ax_ligand_list[i].mol.OBMol.GetTotalCharge()
         # average axial results
         result_ax_dent = np.divide(result_ax_dent, n_ax)
         result_ax_maxdelen = np.divide(result_ax_maxdelen, n_ax)
@@ -208,19 +196,3 @@ def generate_all_ligand_misc_dimers(mol, loud, custom_ligand_dict=False):
     results_dictionary = {'colnames': colnames, 'result_ax1': result_ax1,
                           'result_ax2': result_ax2, 'result_ax3': result_ax3}
     return results_dictionary
-
-
-def get_lig_EN(mol, connection_atoms):
-    # calculate the maximum abs electronegativity
-    # difference between connection atom an all
-    # neighbors
-    max_EN = 0
-    globs = globalvars()
-    for atoms in connection_atoms:
-        this_atoms_neighbors = mol.getBondedAtomsSmart(atoms)
-        for bound_atoms in this_atoms_neighbors:
-            this_EN = float(globs.endict()[mol.getAtom(atoms).symbol(
-            )]) - float(globs.endict()[mol.getAtom(bound_atoms).symbol()])
-            if (abs(this_EN) >= max_EN):
-                max_EN = this_EN
-    return max_EN
