@@ -171,7 +171,6 @@ def import_from_cif(fst, return_extra_cif_info=False):
 def center_of_sym(list_of_points):
     n = len(list_of_points)
 #    print('lop = ' + str(list_of_points))
-    csym = [0, 0, 0]
     csym = [float(sum(x)/n) for x in zip(*list_of_points)]
     return csym
 # get sets min z coord of mol3D to zero
@@ -512,20 +511,19 @@ def shave__type(super_cell, dim, mode):
 
     dim_ref = 1000
 
+    del_list = []
     if (mode == -1):
         for i, atoms in enumerate(super_cell.getAtoms()):
             coords = atoms.coords()
             if (coords[dim] < dim_ref):
                 dim_ref = coords[dim]
-        del_list = list()
         for i, atoms in enumerate(super_cell.getAtoms()):
             coords = atoms.coords()
             if abs(coords[dim] - dim_ref) < TOL:
                 del_list.append(i)
-    if (mode == 1):
+    elif (mode == 1):
         extents = find_extents(super_cell)
         dim_max = extents[dim]
-        del_list = list()
         for i, atoms in enumerate(super_cell.getAtoms()):
             coords = atoms.coords()
             if abs(coords[dim] - dim_max) < TOL:
