@@ -30,7 +30,8 @@ from molSimplify.Scripts.rungen import (constrgen,
 def startgen_pythonic(input_dict={'-core': 'fe', '-lig': 'cl,cl,cl,cl,cl,cl'},
                       argv=['main.py', '-i', 'asdfasdfasdfasdf'],
                       flag=True,
-                      gui=False):
+                      gui=False,
+                      write=False):
     """This is the main way to generate structures completely within Python.
 
         Parameters
@@ -43,6 +44,8 @@ def startgen_pythonic(input_dict={'-core': 'fe', '-lig': 'cl,cl,cl,cl,cl,cl'},
                 Flag for printing information. Default is True.
             gui : bool, optional
                 Flag for GUI. Default is False.
+            write : bool, optional
+                Flag to generate outputfile from python
 
         Returns
         -------
@@ -50,14 +53,17 @@ def startgen_pythonic(input_dict={'-core': 'fe', '-lig': 'cl,cl,cl,cl,cl,cl'},
                 Folder containing the runs.
             emsg : bool
                 Flag for error. If error, returns a string with error.
-            this_diag : rundiag 
+            this_diag : rundiag
                 Rundiag class instance that contains ANN attributes (this_diag.ANN_attributes) and a mol3D class instance (this_diag.mol).
-            
+
     """
     # from molSimplify.Scripts.generator import startgen_pythonic
     inputfile_str = '\n'.join([k + ' ' + v for k, v in list(input_dict.items())])
-    strfiles, emsg, this_diag = startgen(argv, flag, gui, inputfile_str, write_files=False)
-    return (strfiles, emsg, this_diag)
+    if write:
+        startgen(argv, flag, gui, inputfile_str, write_files=write)
+    else:
+        strfiles, emsg, this_diag = startgen(argv, flag, gui, inputfile_str, write_files=write)
+        return (strfiles, emsg, this_diag)
 
 
 # Coordinates subroutines
@@ -96,14 +102,13 @@ def startgen(argv, flag, gui, inputfile_str=None, write_files=True):
     #    instdir = raw_input("Please select the full path of the top installation directory for the program: ")
     #    cdbdir = raw_input("Please specify the full path of the directory containing chemical databases:")
     #    mwfn = raw_input("Specify the full path to the Multiwfn executable (for post-processing):")
-    #    f = open(homedir+'/.molSimplify','w')
-    #    if len(instdir) > 1:
-    #        f.write("INSTALLDIR="+instdir+'\n')
-    #    if len(cdbdir) > 1:
-    #        f.write("CHEMDBDIR="+cdbdir+'\n')
-    #    if len(mwfn) > 1 :
-    #        f.write("MULTIWFN="+mwfn[0]+'\n')
-    #    f.close()
+    #    with open(homedir+'/.molSimplify','w') as f:
+    #        if len(instdir) > 1:
+    #            f.write("INSTALLDIR="+instdir+'\n')
+    #        if len(cdbdir) > 1:
+    #            f.write("CHEMDBDIR="+cdbdir+'\n')
+    #        if len(mwfn) > 1 :
+    #            f.write("MULTIWFN="+mwfn[0]+'\n')
     ### end set-up configuration file ###
     ############ GLOBALS DEFINITION ############
     globs = globalvars()
@@ -206,7 +211,7 @@ def startgen(argv, flag, gui, inputfile_str=None, write_files=True):
                 del args
                 return emsg
     elif args.drawmode:
-        emsg = draw_supervisor(args, rundir)
+        draw_supervisor(args, rundir)
     # slab/place on slab?
     elif (args.slab_gen or args.place_on_slab):
         emsg = slab_module_supervisor(args, rundir)
@@ -253,7 +258,3 @@ def startgen(argv, flag, gui, inputfile_str=None, write_files=True):
         print(ss)
     del args
     return emsg
-
-
-if __name__ == "__main__":
-    startgen()
