@@ -30,66 +30,71 @@ def sgejobgen(args, jobdirs):
         else:
             jobname = 'job'+str(args.jid)
         args.jid += 1
-        output = open(job+'/'+'jobscript', 'w')
-        output.write('#$ -S /bin/bash\n')
-        output.write('#$ -N %s\n' % (jobname))
-        output.write('#$ -R y\n')
-        output.write('#$ -cwd\n')
+        output = []
+        output.append('#$ -S /bin/bash\n')
+        output.append('#$ -N %s\n' % (jobname))
+        output.append('#$ -R y\n')
+        output.append('#$ -cwd\n')
         if not args.wtime:
-            output.write('#$ -l h_rt=168:00:00\n')
+            output.append('#$ -l h_rt=168:00:00\n')
         else:
             wtime = args.wtime.split(':')[0]
             wtime = wtime.split('h')[0]
-            output.write('#$ -l h_rt='+wtime+':00:00\n')
+            output.append('#$ -l h_rt='+wtime+':00:00\n')
         if not args.memory:
-            output.write('#$ -l h_rss=8G\n')
+            output.append('#$ -l h_rss=8G\n')
         else:
             mem = args.memory.split('G')[0]
-            output.write('#$ -l h_rss='+mem+'G\n')
+            output.append('#$ -l h_rss='+mem+'G\n')
         if not args.queue:
             if args.qccode and args.qccode in 'terachem TeraChem TERACHEM tc TC Terachem':
-                output.write('#$ -q gpus\n')
+                output.append('#$ -q gpus\n')
                 if args.gpus:
-                    output.write('#$ -l gpus='+args.gpus+'\n')
+                    output.append('#$ -l gpus='+args.gpus+'\n')
                 else:
-                    output.write('#$ -l gpus=1\n')
+                    output.append('#$ -l gpus=1\n')
             else:
-                output.write('#$ -q cpus\n')
+                output.append('#$ -q cpus\n')
                 if args.cpus:
-                    output.write('#$ -l cpus='+args.cpus+'\n')
+                    output.append('#$ -l cpus='+args.cpus+'\n')
                     cpus = args.cpus
                 else:
-                    output.write('#$ -l cpus=1\n')
+                    output.append('#$ -l cpus=1\n')
         else:
-            output.write('#$ -q '+args.queue+'\n')
+            output.append('#$ -q '+args.queue+'\n')
             if args.cpus:
-                output.write('#$ -l cpus='+args.cpus+'\n')
+                output.append('#$ -l cpus='+args.cpus+'\n')
                 cpus = args.cpus
             elif args.gpus:
-                output.write('#$ -l gpus='+args.gpus+'\n')
+                output.append('#$ -l gpus='+args.gpus+'\n')
             else:
-                output.write('#$ -l gpus=1\n')
+                output.append('#$ -l gpus=1\n')
         if args.gpus:
-            output.write('#$ -pe smp '+args.gpus+'\n')
+            output.append('#$ -pe smp '+args.gpus+'\n')
         elif args.cpus:
-            output.write('#$ -pe smp '+args.cpus+'\n')
+            output.append('#$ -pe smp '+args.cpus+'\n')
         else:
-            output.write('#$ -pe smp 1\n')
+            output.append('#$ -pe smp 1\n')
         if args.joption:
+            multi_option = args.joption[0].split('-')
+            if len(multi_option) > 1:
+                args.joption = []
+                for option in multi_option[1:]:
+                    args.joption += ["-" + option]
             for jopt in args.joption:
-                output.write('# '+jopt+'\n')
+                output.append('# '+jopt+'\n')
         if args.modules:
             for mod in args.modules:
-                output.write('module load '+mod+'\n')
+                output.append('module load '+mod+'\n')
         if args.gpus:
-            output.write('export OMP_NUM_THREADS='+args.gpus+'\n')
+            output.append('export OMP_NUM_THREADS='+args.gpus+'\n')
         elif args.cpus:
-            output.write('export OMP_NUM_THREADS='+args.cpus+'\n')
+            output.append('export OMP_NUM_THREADS='+args.cpus+'\n')
         else:
-            output.write('export OMP_NUM_THREADS=1\n')
+            output.append('export OMP_NUM_THREADS=1\n')
         if args.jcommand:
             for com in args.jcommand:
-                output.write(com+'\n')
+                output.append(com+'\n')
         if args.qccode and args.qccode in 'terachem TeraChem TERACHEM tc TC Terachem':
             tc = False
             if args.jcommand:
@@ -97,8 +102,9 @@ def sgejobgen(args, jobdirs):
                     if 'terachem' in jc:
                         tc = True
             if not tc:
-                output.write(
+                output.append(
                     'terachem terachem_input > $SGE_O_WORKDIR/opttest.out')
+            output.append('\n\nsleep 30')
         elif args.qccode and ('gam' in args.qccode.lower() or 'qch' in args.qccode.lower()):
             gm = False
             qch = False
@@ -109,9 +115,10 @@ def sgejobgen(args, jobdirs):
                     if 'qchem' in jc:
                         qch = True
             if not gm and 'gam' in args.qccode.lower():
-                output.write('rungms gam.inp '+cpus + ' > gam.out')
+                output.append('rungms gam.inp '+cpus + ' > gam.out')
             elif not qch and 'qch' in args.qccode.lower():
-                output.write('qchem qch.inp '+cpus + ' > qch.out')
+                output.append('qchem qch.inp '+cpus + ' > qch.out')
+            output.append('\n\nsleep 30')
         elif args.qccode and ('orc' in args.qccode.lower() or 'molc' in args.qccode.lower()):
             orc = False
             molc = False
@@ -122,13 +129,15 @@ def sgejobgen(args, jobdirs):
                     if 'molcas' in jc:
                         molc = True
             if not orc and 'orca' in args.qccode.lower():
-                output.write('orca orca.in > orca.out')
+                output.append('orca orca.in > orca.out')
             elif not molc and 'molc' in args.qccode.lower():
-                output.write('pymolcas molcas.input -f')
+                output.append('pymolcas molcas.input -f')
+            output.append('\n\nsleep 30')
         else:
             print(
                 'Not supported QC code requested. Please input execution command manually')
-        output.close()
+        with open(job+'/'+'jobscript', 'w') as f:
+            f.writelines(output)
 
 # Generates jobscripts for SLURM queueing system
 #  @param args Namespace of arguments
@@ -155,48 +164,48 @@ def slurmjobgen(args, jobdirs):
         else:
             jobname = 'job'+str(args.jid)
         args.jid += 1
-        output = open(job+'/'+'jobscript', 'w')
-        output.write('#!/bin/bash\n')
-        output.write('#SBATCH --job-name=%s\n' % (jobname))
-        output.write('#SBATCH --output=batch.log\n')
-        output.write('#SBATCH --export=ALL\n')
+        output = []
+        output.append('#!/bin/bash\n')
+        output.append('#SBATCH --job-name=%s\n' % (jobname))
+        output.append('#SBATCH --output=batch.log\n')
+        output.append('#SBATCH --export=ALL\n')
         if not args.wtime:
-            output.write('#SBATCH -t 168:00:00\n')
+            output.append('#SBATCH -t 168:00:00\n')
         else:
             wtime = args.wtime.split(':')[0]
             wtime = wtime.split('h')[0]
-            output.write('#SBATCH -t '+wtime+':00:00\n')
+            output.append('#SBATCH -t '+wtime+':00:00\n')
         if not args.memory:
-            output.write('#SBATCH --mem==8G\n')
+            output.append('#SBATCH --mem==8G\n')
         else:
             mem = args.memory.split('G')[0]
-            output.write('#SBATCH --mem='+mem+'G\n')
+            output.append('#SBATCH --mem='+mem+'G\n')
         if not args.queue:
             if args.qccode and args.qccode in 'terachem TeraChem TERACHEM tc TC Terachem':
-                output.write('#SBATCH --partition=gpus\n')
+                output.append('#SBATCH --partition=gpus\n')
             else:
-                output.write('#SBATCH --partition=cpus\n')
+                output.append('#SBATCH --partition=cpus\n')
         else:
-            output.write('#SBATCH --partition='+args.queue+'\n')
+            output.append('#SBATCH --partition='+args.queue+'\n')
         nod = False
         nnod = False
         if args.joption:
             for jopt in args.joption:
-                output.write('#SBATCH '+jopt+'\n')
+                output.append('#SBATCH '+jopt+'\n')
                 if 'nodes' in jopt:
                     nod = True
                 if 'ntasks' in jopt:
                     nnod = True
         if not nod:
-            output.write('#SBATCH --nodes=1\n')
+            output.append('#SBATCH --nodes=1\n')
         if not nnod:
-            output.write('#SBATCH --ntasks-per-node=1\n')
+            output.append('#SBATCH --ntasks-per-node=1\n')
         if args.modules:
             for mod in args.modules:
-                output.write('module load '+mod+'\n')
+                output.append('module load '+mod+'\n')
         if args.jcommand:
             for com in args.jcommand:
-                output.write(com+'\n')
+                output.append(com+'\n')
         if args.qccode and args.qccode in 'terachem TeraChem TERACHEM tc TC Terachem':
             tc = False
             if args.jcommand:
@@ -204,7 +213,7 @@ def slurmjobgen(args, jobdirs):
                     if 'terachem' in jc:
                         tc = True
             if not tc:
-                output.write('terachem terachem_input > tc.out')
+                output.append('terachem terachem_input > tc.out')
         elif args.qccode and ('gam' in args.qccode.lower() or 'qch' in args.qccode.lower()):
             gm = False
             qch = False
@@ -215,9 +224,9 @@ def slurmjobgen(args, jobdirs):
                     if 'qchem' in jc:
                         qch = True
             if not gm and 'gam' in args.qccode.lower():
-                output.write('rungms gam.inp '+cpus + ' > gam.out')
+                output.append('rungms gam.inp '+cpus + ' > gam.out')
             elif not qch and 'qch' in args.qccode.lower():
-                output.write('qchem qch.inp '+cpus + ' > qch.out')
+                output.append('qchem qch.inp '+cpus + ' > qch.out')
         elif args.qccode and ('orc' in args.qccode.lower() or 'molc' in args.qccode.lower()):
             orc = False
             molc = False
@@ -228,10 +237,11 @@ def slurmjobgen(args, jobdirs):
                     if 'molcas' in jc:
                         molc = True
             if not orc and 'orca' in args.qccode.lower():
-                output.write('orca orca.in > orca.out')
+                output.append('orca orca.in > orca.out')
             elif not molc and 'molc' in args.qccode.lower():
-                output.write('pymolcas molcas.input -f')
+                output.append('pymolcas molcas.input -f')
         else:
             print(
                 'No supported QC code requested. Please input execution command manually')
-        output.close()
+        with open(job+'/'+'jobscript', 'w') as f:
+            f.writelines(output)
