@@ -58,7 +58,7 @@ def read_outfile(outfile_path, short_ouput=False, long_output=True):
                                'thermo_vib_energy': None, 'thermo_vib_free_energy': None, 'thermo_suspect': None,
                                'orbital_occupation': None, 'oscillating_scf_error': False}
                 return return_dict
-                
+
     output_type = ['TeraChem', 'ORCA'][counter]
 
     name = None
@@ -308,7 +308,7 @@ def read_infile(outfile_path):
     for prop, prop_name in zip([unique_job_name, charge, spinmult, solvent, run_type, levelshifta, levelshiftb, method, hfx,
                                 basis, convergence_thresholds, multibasis, constraints, dispersion, coordinates, guess,
                                 qm_code],
-                               ['name', 'charge', 'spinmult', 'solvent', 'run_type', 'levelshifta', 'levelshiftb', 
+                               ['name', 'charge', 'spinmult', 'solvent', 'run_type', 'levelshifta', 'levelshiftb',
                                 'method', 'hfx',
                                 'basis', 'convergence_thresholds', 'multibasis', 'constraints', 'dispersion',
                                 'coordinates', 'guess', 'qm_code']):
@@ -332,9 +332,8 @@ def read_configure(home_directory, outfile_path):
 
         configure = os.path.join(directory, 'configure')
         if os.path.isfile(configure):
-            f = open(configure, 'r')
-            configure = f.readlines()
-            f.close()
+            with open(configure, 'r') as f:
+                configure = f.readlines()
             configure = list(map(strip_new_line, configure))
             return configure
         else:
@@ -546,7 +545,6 @@ def write_terachem_input(infile_dictionary):
     if infile['spinmult'] != 1:
         infile['method'] = 'u' + infile['method']
 
-    input_file = open(infile['name'] + '.in', 'w')
     text = ['levelshiftvalb ' + str(infile['levelshiftb']) + '\n',
             'levelshiftvala ' + str(infile['levelshifta']) + '\n',
             'run ' + infile['run_type'] + '\n',
@@ -585,8 +583,8 @@ def write_terachem_input(infile_dictionary):
     if type(infile['convergence_thresholds']) == list:
         if infile['convergence_thresholds'][0]:
             thresholds = [line if line.endswith('\n') else line + '\n' for line in infile['convergence_thresholds']]
-            tight_thresholds = ("min_converge_gmax " + thresholds[0] + "min_converge_grms " 
-                                + thresholds[1] + "min_converge_dmax " + thresholds[2] 
+            tight_thresholds = ("min_converge_gmax " + thresholds[0] + "min_converge_grms "
+                                + thresholds[1] + "min_converge_dmax " + thresholds[2]
                                 + "min_converge_drms " + thresholds[3] + "min_converge_e "
                                 + thresholds[4] + "convthre " + thresholds[5])
             text = text[:-1] + ['\n', tight_thresholds, 'end']
@@ -621,9 +619,9 @@ def write_terachem_input(infile_dictionary):
     else:
         raise ValueError('Machine not known!')
 
-    for lines in text:
-        input_file.write(lines)
-    input_file.close()
+    with open(infile['name'] + '.in', 'w') as fout:
+        for lines in text:
+            fout.write(lines)
 
 
 def write_orca_input(infile_dictionary):
@@ -657,7 +655,6 @@ def write_orca_input(infile_dictionary):
     if infile['run_type'] == 'minimize':
         infile['run_type'] = 'opt'
 
-    input_file = open(infile['name'] + '.in', 'w')
     # Note that max core is set to 2000MB, this is 2/3 of the amount allocated in the jobscript (on a per processor basis)
     # The SCF is known (according to the ORCA manual) to exceed allotted memory, so this provides some wiggle room
     if not infile['solvent']:
@@ -679,34 +676,33 @@ def write_orca_input(infile_dictionary):
     if infile['custom_line']:
         text = text + [infile['custom_line'] + '\n']
 
-    for lines in text:
-        input_file.write(lines)
-    input_file.close()
+    with open(infile['name'] + '.in', 'w') as input_file:
+        for lines in text:
+            input_file.write(lines)
 
 
 def write_jobscript(name, custom_line=None, time_limit='96:00:00', qm_code='terachem', parallel_environment=4,
-                    machine='gibraltar', cwd=False, use_molscontrol=False, queues=['gpus', 'gpusnew']):
+                    machine='gibraltar', use_molscontrol=False, queues=['gpus', 'gpusnew']):
     # Writes a generic obscript
     # custom line allows the addition of extra lines just before the export statement
 
     if qm_code == 'terachem':
-        write_terachem_jobscript(name, custom_line=custom_line, time_limit=time_limit, 
-                                 machine=machine, cwd=cwd,
-                                 use_molscontrol=use_molscontrol, queues=queues)
+        write_terachem_jobscript(name, custom_line=custom_line, time_limit=time_limit,
+                                 machine=machine, use_molscontrol=use_molscontrol,
+                                 queues=queues)
     elif qm_code == 'orca':
         write_orca_jobscript(name, custom_line=custom_line, time_limit=time_limit,
-                             parallel_environment=parallel_environment, 
-                             machine=machine,
-                             use_molscontrol=use_molscontrol)
+                             parallel_environment=parallel_environment,
+                             machine=machine, use_molscontrol=use_molscontrol)
     else:
         raise Exception('QM code: ' + qm_code + ' not recognized for jobscript writing!')
 
 
-def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', terachem_line=True, 
-                             machine='gibraltar', cwd=False, use_molscontrol=False, queues=['gpus', 'gpusnew']):
+def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', terachem_line=True,
+                             machine='gibraltar', use_molscontrol=False, queues=['gpus', 'gpusnew']):
     # if use_molscontrol and machine != 'gibraltar':
     #     raise ValueError("molscontrol is only implemented on gibraltar for now.")
-    jobscript = open(name + '_jobscript', 'w')
+
     if machine == 'gibraltar':
         if not use_molscontrol:
             text = ['#$ -S /bin/bash\n',
@@ -800,28 +796,15 @@ def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', tera
         raise ValueError('Job manager does not know how to run Terachem on this machine!')
     if terachem_line and machine == 'gibraltar':
         if not use_molscontrol:
-            if not cwd:
-                text += ['terachem ' + name + '.in ' + '> $SGE_O_WORKDIR/' + name + '.out\n']
-            else:
-                text += ["echo $SGE_O_WORKDIR\n"]
-                text += ['cd $SGE_O_WORKDIR\n']
-                text += ['terachem ' + name + '.in ' + '> ' + name + '.out\n']
+            text += ['terachem ' + name + '.in ' + '> $SGE_O_WORKDIR/' + name + '.out\n']
         else:
             text += ["cp %s.xyz initgeo.xyz" % name]
-            if not cwd:
-                text += ['terachem ' + name + '.in ' + '> $SGE_O_WORKDIR/' + name + '.out &\n']
-                text += ["PID_KILL=$!\n"]
-                text += ["molscontrol $PID_KILL &\n"]
-                text += ["wait\n"]
-                text += ["mv *.log $SGE_O_WORKDIR\n"]
-                text += ["mv features.json $SGE_O_WORKDIR/dyanmic_features.json\n"]
-            else:
-                text += ["echo $SGE_O_WORKDIR\n"]
-                text += ['cd $SGE_O_WORKDIR\n']
-                text += ['terachem ' + name + '.in ' + '> ' + name + '.out &\n']
-                text += ["PID_KILL=$!\n"]
-                text += ["molscontrol $PID_KILL &\n"]
-                text += ["wait\n"]
+            text += ['terachem ' + name + '.in ' + '> $SGE_O_WORKDIR/' + name + '.out &\n']
+            text += ["PID_KILL=$!\n"]
+            text += ["molscontrol $PID_KILL &\n"]
+            text += ["wait\n"]
+            text += ["mv *.log $SGE_O_WORKDIR\n"]
+            text += ["mv features.json $SGE_O_WORKDIR/dyanmic_features.json\n"]
     elif terachem_line and machine in ['bridges', 'comet']:
         text += ['terachem ' + name + '.in ' + '> ' + name + '.out\n']
     if custom_line:
@@ -829,10 +812,11 @@ def write_terachem_jobscript(name, custom_line=None, time_limit='96:00:00', tera
             text = text[:12] + custom_line + text[12:]
         else:
             text = text[:12] + [custom_line + '\n'] + text[12:]
+    text += ['sleep 30']
 
-    for i in text:
-        jobscript.write(i)
-    jobscript.close()
+    with open(name + '_jobscript', 'w') as jobscript:
+        for i in text:
+            jobscript.write(i)
 
 
 def write_molscontrol_config():
@@ -840,12 +824,15 @@ def write_molscontrol_config():
 
 
 def write_orca_jobscript(name, custom_line=None, time_limit='96:00:00', parallel_environment=4,
-                         machine='gibraltar'):
+                         machine='gibraltar', use_molscontrol=False):
     # Write a generic orca jobscript
 
+    if use_molscontrol:
+        raise NotImplementedError('molscontrol is currently not supported for orca.')
+
     memory_allocation = str(
         int(parallel_environment) * 3)  # allocate memory based on 192 GB for 64 processors on the new cpu nodes
-    jobscript = open(name + '_jobscript', 'w')
+
     if machine == 'gibraltar':
         text = ['#$ -S /bin/bash\n',
                 '#$ -N ' + name + '\n',
@@ -878,9 +865,9 @@ def write_orca_jobscript(name, custom_line=None, time_limit='96:00:00', parallel
         else:
             text = text[:12] + [custom_line + '\n'] + text[12:]
 
-    for i in text:
-        jobscript.write(i)
-    jobscript.close()
+    with open(name + '_jobscript', 'w') as jobscript:
+        for i in text:
+            jobscript.write(i)
 
 
 def get_scf_progress(outfile):
