@@ -277,9 +277,8 @@ def list_active_jobs(ids=False, home_directory=False, parse_bundles=False):
 
     if parse_bundles and os.path.isfile(os.path.join(home_directory, 'bundle', 'bundle_id')):
 
-        fil = open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'r')
-        identifier = fil.readlines()[0]
-        fil.close()
+        with open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'r') as fil:
+            identifier = fil.readlines()[0]
 
         bundles = [i for i in names if i.startswith('bundle_')]
         bundles = [i.rsplit('_', 1)[0] for i in names if i.endswith(identifier)]
@@ -287,10 +286,9 @@ def list_active_jobs(ids=False, home_directory=False, parse_bundles=False):
 
         for bundle in bundles:
             info_path = glob.glob(os.path.join(home_directory, 'bundle', bundle, '*_info'))[0]
-            fil = open(info_path, 'r')
-            lines = fil.readlines()
+            with open(info_path, 'r') as fil:
+                lines = fil.readlines()
             lines = [i[:-1] if i.endswith('\n') else i for i in lines]
-            fil.close()
             names.extend(lines)
 
     return names
@@ -322,11 +320,10 @@ def get_number_active():
     active_non_bundles = [i for i in outfiles if check_active(i)]
 
     if os.path.isdir('bundle'):
-        fil = open(os.path.join('bundle', 'bundle_id'))
-        identifier = fil.readlines()[0]
+        with open(os.path.join('bundle', 'bundle_id')) as fil:
+            identifier = fil.readlines()[0]
         if identifier.endswith('\n'):
             identifier = identifier[:-1]
-        fil.close()
 
         active_bundles = [i for i in active_jobs if i.startswith('bundle_')]
         active_bundles = [i for i in active_jobs if i.endswith(identifier)]
@@ -651,9 +648,8 @@ def extract_optimized_geo(PATH, custom_name=False):
     # Given the path to an optim.xyz file, this will extract optimized.xyz, which contains only the last frame
     # The file is written to the same directory as contained optim.xyz
 
-    optim = open(PATH, 'r')
-    lines = optim.readlines()
-    optim.close()
+    with open(PATH, 'r') as optim:
+        lines = optim.readlines()
     lines.reverse()
     if len(lines) == 0:
         lines = []
@@ -674,10 +670,9 @@ def extract_optimized_geo(PATH, custom_name=False):
     else:
         name = 'optimized.xyz'
 
-    optimized = open(os.path.join(homedir, name), 'w')
-    for i in lines:
-        optimized.write(i)
-    optimized.close()
+    with open(os.path.join(homedir, name), 'w') as optimized:
+        for i in lines:
+            optimized.write(i)
 
     return lines
 
@@ -779,12 +774,10 @@ def sub_bundle_jobscripts(home_directory, jobscript_paths):
     # Records information about which jobs were bundled together in the run's home directory
     if not os.path.isdir(os.path.join(home_directory, 'bundle')):
         os.mkdir(os.path.join(home_directory, 'bundle'))
-        fil = open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'w')
-        fil.write(str(np.random.randint(100000000000)))
-        fil.close()
-    fil = open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'r')
-    identifier = fil.readlines()[0]
-    fil.close()
+        with open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'w') as fil:
+            fil.write(str(np.random.randint(100000000000)))
+    with open(os.path.join(home_directory, 'bundle', 'bundle_id'), 'r') as fil:
+        identifier = fil.readlines()[0]
 
     jobscript_paths = [convert_to_absolute_path(i) for i in jobscript_paths]
 
@@ -799,12 +792,11 @@ def sub_bundle_jobscripts(home_directory, jobscript_paths):
     os.mkdir(os.path.join(home_directory, 'bundle', 'bundle_' + str(max(existing_bundle_numbers) + 1)))
 
     # Record info about how the jobs are being bundled
-    fil = open(os.path.join(home_directory, 'bundle', 'bundle_' + str(max(existing_bundle_numbers) + 1),
-                            'bundle_' + str(max(existing_bundle_numbers) + 1) + '_info'), 'w')
-    for i in jobscript_paths[:-1]:
-        fil.write(os.path.split(i)[-1].rsplit('_', 1)[0] + '\n')
-    fil.write(os.path.split(jobscript_paths[-1])[-1].rsplit('_', 1)[0])
-    fil.close()
+    with open(os.path.join(home_directory, 'bundle', 'bundle_' + str(max(existing_bundle_numbers) + 1),
+                           'bundle_' + str(max(existing_bundle_numbers) + 1) + '_info'), 'w') as fil:
+        for i in jobscript_paths[:-1]:
+            fil.write(os.path.split(i)[-1].rsplit('_', 1)[0] + '\n')
+        fil.write(os.path.split(jobscript_paths[-1])[-1].rsplit('_', 1)[0])
 
     # Write a jobscript for the job bundle
     home = os.getcwd()
@@ -813,14 +805,13 @@ def sub_bundle_jobscripts(home_directory, jobscript_paths):
                                         terachem_line=False, time_limit='12:00:00', machine=get_machine())
     shutil.move('bundle_' + str(max(existing_bundle_numbers) + 1) + '_' + identifier + '_jobscript',
                 'bundle_' + str(max(existing_bundle_numbers) + 1))
-    fil = open('bundle_' + str(max(existing_bundle_numbers) + 1), 'a')
-    for i in jobscript_paths:
-        infile = i.rsplit('_', 1)[0] + '.in'
-        outfile = i.rsplit('_', 1)[0] + '.out'
-        directory = os.path.split(i)[0]
-        text = 'cd ' + directory + '\n' + 'terachem ' + infile + ' > ' + outfile
-        fil.write(text + '\n')
-    fil.close()
+    with open('bundle_' + str(max(existing_bundle_numbers) + 1), 'a') as fil:
+        for i in jobscript_paths:
+            infile = i.rsplit('_', 1)[0] + '.in'
+            outfile = i.rsplit('_', 1)[0] + '.out'
+            directory = os.path.split(i)[0]
+            text = 'cd ' + directory + '\n' + 'terachem ' + infile + ' > ' + outfile
+            fil.write(text + '\n')
     os.chdir(home)
 
     return os.path.join(home_directory, 'bundle', 'bundle_' + str(max(existing_bundle_numbers) + 1),
@@ -1126,9 +1117,8 @@ def prep_functionals_sp(path, functionalsSP):
 
         manager_io.write_input(local_infile_dict)
 
-        fil = open('configure', 'w')
-        fil.write('method:' + func)
-        fil.close()
+        with open('configure', 'w') as fil:
+            fil.write('method:' + func)
         os.chdir(home)
         jobscripts.append(os.path.join(PATH, name + '_jobscript'))
     os.chdir(home)
@@ -1399,8 +1389,8 @@ def prep_ultratight(path):
         manager_io.write_input(local_infile_dict)
 
         # Make an empty .out file to prevent the resubmission module from mistakenly submitting this job twice
-        f = open(name + '.out', 'w')
-        f.close()
+        with open(name + '.out', 'w') as _:
+            pass
 
         os.chdir(home)
 
