@@ -58,7 +58,7 @@ def ensemble_maker_inner(train_mat, labels, model_gen_function, info_dict,
     ## contains core functions to make ensemble models
     ## from training data and labels
     ## model_gen_function is a functiont that takes NO arguments and returns a keras model
-    ## info_dict is a dictionary of training info 
+    ## info_dict is a dictionary of training info
     train_mat, labels = shuffle(train_mat, labels)
     train_mat = np.array_split(train_mat, num, axis=0)
     labels = np.array_split(labels, num, axis=0)
@@ -130,9 +130,8 @@ def ensemble_uq(predictor, descriptors=False, descriptor_names=False, suffix=Fal
     # print('models', model_list)
     for idx, model in enumerate(model_list):
         _base = model.split('.')[0]
-        json_file = open(_base + '.json', 'r')
-        loaded_model_json = json_file.read()
-        json_file.close()
+        with open(_base + '.json', 'r') as json_file:
+            loaded_model_json = json_file.read()
         loaded_model = model_from_json(loaded_model_json)
         # load weights into  model
         loaded_model.load_weights(model)
@@ -243,9 +242,8 @@ def latent_space_uq(predictor, layer_index=-2, descriptors=False, descriptor_nam
     dist_list = []
     for model in model_list:
         _base = model.split('.')[0]
-        json_file = open(_base + '.json', 'r')
-        loaded_model_json = json_file.read()
-        json_file.close()
+        with open(_base + '.json', 'r') as json_file:
+            loaded_model_json = json_file.read()
         loaded_model = model_from_json(loaded_model_json)
         loaded_model.load_weights(model)
         loaded_model.compile(loss="mse", optimizer='adam',
@@ -264,13 +262,13 @@ def latent_space_uq(predictor, layer_index=-2, descriptors=False, descriptor_nam
         ## get latent dist
         training_latent_distance = np.array(get_latent([excitation, 0]))[0]
         nn_latent_dist_train, _, __ = dist_neighbor(training_latent_distance, training_latent_distance, labels_train,
-                                                    l=5, dist_ref=1, just_nn=True)
+                                                    l=5, dist_ref=1)
         nn_dist_avrg_train = np.mean(nn_latent_dist_train)
         # print(nn_dist_avrg_train)
         test_latent_distance = np.array(get_latent([excitation_test, 0]))[0]
         nn_latent_dist_test, nn_dists, nn_labels = dist_neighbor(test_latent_distance, training_latent_distance,
                                                                  labels_train,
-                                                                 l=5, dist_ref=nn_dist_avrg_train, just_nn=False)
+                                                                 l=5, dist_ref=nn_dist_avrg_train)
         if not entropy:
             # print(nn_latent_dist_test.shape)
             # print(min(nn_latent_dist_test), max(nn_latent_dist_test))
