@@ -16,6 +16,7 @@ import os
 import numpy as np
 import pandas as pd
 import scipy
+from typing import List, Tuple, Union
 from tensorflow.keras import backend as K
 from tensorflow.keras.models import model_from_json, load_model
 from tensorflow.keras.optimizers import Adam
@@ -25,21 +26,20 @@ import tensorflow as tf
 from molSimplify.python_nn.clf_analysis_tool import array_stack, get_layer_outputs, dist_neighbor, get_entropy
 
 
-## Functions
-
-def perform_ANN_prediction(RAC_dataframe, predictor_name, RAC_column='RACs'):
+def perform_ANN_prediction(RAC_dataframe: pd.DataFrame, predictor_name: str,
+                           RAC_column: str = 'RACs') -> pd.DataFrame:
     # Performs a correctly normalized/rescaled prediction for a property specified by predictor_name.
     # Also calculates latent vector and smallest latent distance from training data.
-    # RAC_dataframe can contain anything (e.g. a database pull) as long as it also contains the required RAC features. 
+    # RAC_dataframe can contain anything (e.g. a database pull) as long as it also contains the required RAC features.
     # Predictor_name can be a name like ls_ii, hs_iii, homo, oxo, hat, etc.
     # Input dataframe must have all RAC features in individual columns, or as dictionaries in a single column specified by `RAC_column`.
     # Will not execute if RAC features are missing.
-    
+
     # Returns: RAC_dataframe with new columns added:
-    ## predictor_name_latent_vector
-    ## predictor_name_min_latent_distance,
-    ## predictor_name_prediction
-    
+    # - predictor_name_latent_vector
+    # - predictor_name_min_latent_distance,
+    # - predictor_name_prediction
+
     assert type(RAC_dataframe) == pd.DataFrame
     train_vars = load_ANN_variables(predictor_name)
     train_mean_x, train_mean_y, train_var_x, train_var_y = load_normalization_data(predictor_name)
@@ -65,7 +65,7 @@ def perform_ANN_prediction(RAC_dataframe, predictor_name, RAC_column='RACs'):
     normalized_input = data_normalize(RAC_subset_for_ANN, train_mean_x, train_var_x)
     ANN_prediction = my_ANN.predict(normalized_input)
     rescaled_output = data_rescale(ANN_prediction, train_mean_y, train_var_y)
-    
+
     # Get latent vectors for training data and queried data
     train_x = load_training_data(predictor_name)
     train_x = pd.DataFrame(train_x, columns=train_vars).astype(float)
@@ -76,7 +76,7 @@ def perform_ANN_prediction(RAC_dataframe, predictor_name, RAC_column='RACs'):
     query_latent = get_outputs([normalized_input, 0])[0]
 
     # Append all results to dataframe
-    results_allocation = [None for i in range(len(RAC_dataframe))]
+    results_list = []
     for i in range(len(RAC_dataframe)):
         results_dict = {}
         min_latent_distance = min(np.linalg.norm(training_latent - query_latent[i][:], axis=1))
@@ -86,8 +86,8 @@ def perform_ANN_prediction(RAC_dataframe, predictor_name, RAC_column='RACs'):
         if len(output_value) == 1:  # squash array of length 1 to the value it contains
             output_value = output_value[0]
         results_dict['%s_prediction' % predictor_name] = output_value
-        results_allocation[i] = results_dict
-    results_df = pd.DataFrame(results_allocation, index=RAC_dataframe.index)
+        results_list.append(results_dict)
+    results_df = pd.DataFrame(results_list, index=RAC_dataframe.index)
     RAC_dataframe_with_results = RAC_dataframe.join(results_df)
     return RAC_dataframe_with_results
 
@@ -106,8 +106,8 @@ def get_error_params(latent_distances, errors):
     return results.x
 
 
-def matrix_loader(path, rownames=False):
-    ## loads matrix with rowname option
+def matrix_loader(path: str, rownames: bool = False) -> Union[Tuple[List[List[str]], List[str]], List[List[str]]]:
+    # loads matrix with rowname option
     if rownames:
         path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/python_nn/" + path)
         with open(path_to_file, "r") as f:
@@ -118,12 +118,12 @@ def matrix_loader(path, rownames=False):
     else:
         path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/python_nn/" + path)
         with open(path_to_file, 'r') as csvfile:
-            csv_lines = csv.reader(csvfile, delimiter=',')
-            mat = [a for a in csv_lines]
+            lines = csv.reader(csvfile, delimiter=',')
+            mat = [a for a in lines]
         return mat
 
 
-def get_key(predictor, suffix=False):
+def get_key(predictor: str, suffix: str = None) -> str:
     if suffix:
         if predictor in ['ls_ii', 'hs_ii', 'ls_iii', 'hs_iii']:
             key = 'geos/' + predictor + '_%s' % suffix
@@ -153,7 +153,7 @@ def get_key(predictor, suffix=False):
     return key
 
 
-def data_rescale(scaled_dat, train_mean, train_var, debug=False):
+def data_rescale(scaled_dat, train_mean, train_var, debug=False) -> np.ndarray:
     d = np.shape(train_mean)[0]
     if debug:
         print(('unnormalizing with number of dimensions = ' + str(d)))
@@ -161,14 +161,14 @@ def data_rescale(scaled_dat, train_mean, train_var, debug=False):
     return (dat)
 
 
-def data_normalize(data, train_mean, train_var, debug=False):
+def data_normalize(data, train_mean, train_var, debug=False) -> np.ndarray:
     data = data.astype(float)  # Make sure the data is always in float form
     d = np.shape(train_mean)[0]
     if debug:
         print(('normalizing with number of dimensions = ' + str(d)))
     ### double check the variance in the training data
     delete_ind = list()
-    
+
     if debug:
         print('shape of things in normalize:')
         print(('data.shape ' + str(data.shape)))
@@ -185,10 +185,10 @@ def data_normalize(data, train_mean, train_var, debug=False):
         train_var = np.delete(train_var, delete_ind, axis=0)
 
     scaled_dat = np.divide((data.T - train_mean), np.sqrt(train_var), ).T
-    return (scaled_dat)
+    return scaled_dat
 
 
-def load_normalization_data(name):
+def load_normalization_data(name: str):
     train_mean_x = list()
     path_to_file = resource_filename(Requirement.parse("molSimplify"),
                                      "molSimplify/tf_nn/" + '/rescaling_data/' + name + '_mean_x.csv')
@@ -219,15 +219,11 @@ def load_normalization_data(name):
     else:
         print('---Mean and Variance information do not exist. Calculate from training data...---')
         train_mean_x, train_mean_y, train_var_x, train_var_y = get_data_mean_std(predictor=name)
-    train_mean_x = np.array(train_mean_x)
-    train_var_x = np.array(train_var_x)
-    train_mean_y = np.array(train_mean_y)
-    train_var_y = np.array(train_var_y)
 
-    return train_mean_x, train_mean_y, train_var_x, train_var_y
+    return np.array(train_mean_x), np.array(train_mean_y), np.array(train_var_x), np.array(train_var_y)
 
 
-def get_data_mean_std(predictor):
+def get_data_mean_std(predictor: str):
     if predictor in ['ls_ii', 'hs_ii', 'ls_iii', 'hs_iii']:
         key = 'geos/' + predictor + '_bl_x'
     elif predictor in ['homo', 'gap']:
@@ -272,7 +268,7 @@ def get_data_mean_std(predictor):
     return train_mean_x, train_mean_y, train_var_x, train_var_y
 
 
-def load_ANN_variables(predictor, suffix='vars'):
+def load_ANN_variables(predictor: str, suffix: str = 'vars') -> List[str]:
     key = get_key(predictor, suffix)
     path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key + '.csv')
     names = []
@@ -282,7 +278,7 @@ def load_ANN_variables(predictor, suffix='vars'):
     return names
 
 
-def load_training_data(predictor):
+def load_training_data(predictor: str) -> List[List[str]]:
     if predictor in ['ls_ii', 'hs_ii', 'ls_iii', 'hs_iii']:
         key = 'geos/' + predictor + '_bl_x'
     elif predictor in ['homo', 'gap']:
@@ -350,7 +346,7 @@ def load_test_data(predictor):
     return mat
 
 
-def load_training_labels(predictor):
+def load_training_labels(predictor: str) -> List[List[str]]:
     if predictor in ['ls_ii', 'hs_ii', 'ls_iii', 'hs_iii']:
         key = 'geos/' + predictor + '_bl_y'
     elif predictor in ['homo', 'gap']:
@@ -373,7 +369,7 @@ def load_training_labels(predictor):
     return mat
 
 
-def load_test_labels(predictor):
+def load_test_labels(predictor: str) -> List[List[str]]:
     if predictor in ['ls_ii', 'hs_ii', 'ls_iii', 'hs_iii']:
         key = 'geos/' + predictor + '_bl_y'
     elif predictor in ['homo', 'gap']:
@@ -396,26 +392,24 @@ def load_test_labels(predictor):
     return mat
 
 
-def load_train_info(predictor, suffix='info'):
+def load_train_info(predictor: str, suffix: str = 'info') -> dict:
     key = get_key(predictor, suffix)
     path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key + '.json')
-    json_file = open(path_to_file, 'r')
-    loaded_info_dict = json.loads(json_file.read())
-    json_file.close()
+    with open(path_to_file, 'r') as json_file:
+        loaded_info_dict = json.loads(json_file.read())
     return loaded_info_dict
 
 
-def load_keras_ann(predictor, suffix='model'):
+def load_keras_ann(predictor: str, suffix: str = 'model'):
     ## this function loads the ANN for property
-    ## "predcitor" 
+    ## "predcitor"
     # disable TF output text to reduce console spam
     os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
     key = get_key(predictor, suffix)
     if "clf" not in predictor:
         path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key + '.json')
-        json_file = open(path_to_file, 'r')
-        loaded_model_json = json_file.read()
-        json_file.close()
+        with open(path_to_file, 'r') as json_file:
+            loaded_model_json = json_file.read()
         loaded_model = model_from_json(loaded_model_json)
         # load weights into  model
         path_to_file = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key + '.h5')
@@ -436,15 +430,15 @@ def load_keras_ann(predictor, suffix='model'):
         # loaded_model.compile(loss="mse", optimizer=Adam(beta_2=0.9637165412871632, beta_1=0.7560951483268549,
         #                                                 decay=0.0006651401379502965, lr=0.0007727366541920176),
         #                      metrics=['mse', 'mae', 'mape']) #decomissioned on 06/20/2019 by Aditya. Using hyperparams from oxo20.
-        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.0012838133056087084, beta_1=0.9811686522122317, 
+        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.0012838133056087084, beta_1=0.9811686522122317,
                                                         beta_2=0.8264616523572279, decay=0.0005114008091318582),
                              metrics=['mse', 'mae', 'mape'])
     elif predictor == 'oxo20':
-        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.0012838133056087084, beta_1=0.9811686522122317, 
+        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.0012838133056087084, beta_1=0.9811686522122317,
                                                         beta_2=0.8264616523572279, decay=0.0005114008091318582),
                              metrics=['mse', 'mae', 'mape'])
     elif predictor == 'homo_empty':
-        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.006677578283098809, beta_1=0.8556594887870226, 
+        loaded_model.compile(loss="mse", optimizer=Adam(lr=0.006677578283098809, beta_1=0.8556594887870226,
                                                         beta_2=0.9463468021275508, decay=0.0006621877134674607),
                              metrics=['mse', 'mae', 'mape'])
 
@@ -462,7 +456,7 @@ def load_keras_ann(predictor, suffix='model'):
     return (loaded_model)
 
 
-def tf_ANN_excitation_prepare(predictor, descriptors, descriptor_names):
+def tf_ANN_excitation_prepare(predictor: str, descriptors: List[float], descriptor_names: List[str]) -> np.ndarray:
     ## this function reforms the provided list of descriptors and their
     ## names to match the expectations of the target ANN model.
     ## it does NOT perfrom standardization
@@ -481,14 +475,17 @@ def tf_ANN_excitation_prepare(predictor, descriptors, descriptor_names):
             print(('looking for  ' + str(var_name)))
             print(('Error! variable  ' + str(var_name) + ' not found!'))
             break
-    excitation = np.array(excitation)
-    excitation = np.reshape(excitation, (1, len(target_names)))
-    return excitation
+    output = np.array(excitation)
+    output = np.reshape(output, (1, len(target_names)))
+    return output
 
 
-def ANN_supervisor(predictor, descriptors, descriptor_names, debug=False):
+def ANN_supervisor(predictor: str,
+                   descriptors: List[float],
+                   descriptor_names: List[str],
+                   debug: bool = False) -> Tuple[np.ndarray, np.ndarray]:
     if debug:
-        print(('ANN activated for ' + str(predictor)))    
+        print(('ANN activated for ' + str(predictor)))
 
     ## form the excitation in the corrrect order/variables
     excitation = tf_ANN_excitation_prepare(predictor, descriptors, descriptor_names)
@@ -515,18 +512,21 @@ def ANN_supervisor(predictor, descriptors, descriptor_names, debug=False):
                                      [loaded_model.layers[len(loaded_model.layers) - 2].output])
             latent_space_vector = get_outputs([excitation, 0])  # Using test phase.
         else:
-            latent_space_vector = get_layer_outputs(loaded_model, len(loaded_model.layers) - 2, 
+            latent_space_vector = get_layer_outputs(loaded_model, len(loaded_model.layers) - 2,
                                                     excitation, training_flag=False)
         if debug:
             print('calling ANN model...')
     else:
         latent_space_vector = find_clf_lse(predictor, excitation, loaded_model=loaded_model, ensemble=False,
-                                           modelname=False, debug=debug)
+                                           modelname=None, debug=debug)
     return result, latent_space_vector
 
 
-def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False):
-    # returns scaled euclidean distance to nearest trainning 
+def find_true_min_eu_dist(predictor: str,
+                          descriptors: List[float],
+                          descriptor_names: List[str],
+                          debug: bool = False) -> float:
+    # returns scaled euclidean distance to nearest trainning
     # vector in desciptor space
     train_mean_x, train_mean_y, train_var_x, train_var_y = load_normalization_data(predictor)
 
@@ -538,7 +538,7 @@ def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False)
     mat = load_training_data(predictor)
     train_mat = np.array(mat, dtype='float64')
     ## loop over rows
-    min_dist = 100000000
+    min_dist = 100000000.
     min_ind = 0
     for i, rows in enumerate(train_mat):
         scaled_row = np.squeeze(
@@ -548,10 +548,8 @@ def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False)
             min_dist = this_dist
             min_ind = i
             # best_row = rownames[i]
-            min_row = rows
+            # min_row = rows
 
-    # flatten min row
-    min_row = np.reshape(min_row, excitation.shape)
     if debug:
         print(('min dist EU is ' + str(min_dist)))
     if predictor in ['oxo', 'hat', 'homo', 'gap']:
@@ -566,7 +564,7 @@ def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False)
             csv_lines = list(csv.reader(f))
             print(('Closest Euc Dist Structure:  ' + str(csv_lines[min_ind]).strip('[]') + ' for predictor ' + str(
                 predictor)))
-    # need to get normalized distances 
+    # need to get normalized distances
 
     ########################################################################################
     # Changed by Aditya on 08/13/2018. Previously, nearest neighbor was being found in the #
@@ -576,6 +574,8 @@ def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False)
 
     # train_mean_x,train_mean_y,train_var_x,train_var_y = load_normalization_data(predictor)
 
+    # flatten min row
+    # min_row = np.reshape(min_row, excitation.shape)
     # scaled_excitation = data_normalize(excitation,train_mean_x,train_var_x)
     # scaled_row = data_normalize(min_row,train_mean_x,train_var_x)
     # min_dist = np.linalg.norm(np.subtract(scaled_row,(scaled_excitation)))
@@ -583,7 +583,7 @@ def find_true_min_eu_dist(predictor, descriptors, descriptor_names, debug=False)
 
 
 def find_ANN_10_NN_normalized_latent_dist(predictor, latent_space_vector, debug=False):
-    # returns scaled euclidean distance to nearest trainning 
+    # returns scaled euclidean distance to nearest trainning
     # vector in desciptor space
 
     # average_train_train_10NN = {'homo_empty': 0.43517572, 'oxo20': 0.068675719}
@@ -626,11 +626,11 @@ def find_ANN_10_NN_normalized_latent_dist(predictor, latent_space_vector, debug=
     sorted_dist = np.sort(np.squeeze(dist_array))
     avg_10_NN_dist = np.mean(sorted_dist[0:10])
     norm_avg_10_NN_dist = avg_10_NN_dist/avg_traintrain
-    return norm_avg_10_NN_dist, avg_10_NN_dist, avg_traintrain 
+    return norm_avg_10_NN_dist, avg_10_NN_dist, avg_traintrain
 
 
 def find_ANN_latent_dist(predictor, latent_space_vector, debug=False):
-    # returns scaled euclidean distance to nearest trainning 
+    # returns scaled euclidean distance to nearest trainning
     # vector in desciptor space
     train_mean_x, train_mean_y, train_var_x, train_var_y = load_normalization_data(predictor)
 
@@ -681,8 +681,13 @@ def find_ANN_latent_dist(predictor, latent_space_vector, debug=False):
     return (min_dist)
 
 
-def find_clf_lse(predictor, excitation, loaded_model, ensemble=False, modelname=False,  debug=False):
-    if modelname is False:
+def find_clf_lse(predictor: str,
+                 excitation,
+                 loaded_model,
+                 ensemble: bool = False,
+                 modelname: str = None,
+                 debug: bool = False) -> np.ndarray:
+    if modelname is None:
         modelname = "spectro"
         if predictor == "geo_static_clf":
             avrg_latent_dist = 33.21736244173539
@@ -690,13 +695,12 @@ def find_clf_lse(predictor, excitation, loaded_model, ensemble=False, modelname=
             avrg_latent_dist = 38.276809428032685
         else:
             print("Unknown model type")
-            return -1
+            return np.zeros_like(excitation)
     key = get_key(predictor, suffix='')
     base_path = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key)
     train_mean_x, train_mean_y, train_var_x, train_var_y = load_normalization_data(predictor)
-    fmat_train = load_training_data(predictor)
     labels_train = np.array(load_training_labels(predictor), dtype='int')
-    fmat_train = np.array(fmat_train, dtype='float64')
+    fmat_train = np.array(load_training_data(predictor), dtype='float64')
     fmat_train = data_normalize(fmat_train, train_mean_x, train_var_x,  debug=debug)
     fmat_train = np.array(fmat_train)
     if not ensemble:
@@ -716,7 +720,7 @@ def find_clf_lse(predictor, excitation, loaded_model, ensemble=False, modelname=
             print(base_path)
             print(model_list)
             print(("Error: LSE cannot be calculated with modelname %s--The number of models is wrong." % modelname))
-            return -1
+            return np.zeros_like(excitation)
         fmat_train = np.array_split(fmat_train, 10, axis=0)
         labels_train = np.array_split(labels_train, 10, axis=0)
         entropies_list = []
@@ -739,7 +743,7 @@ def find_clf_lse(predictor, excitation, loaded_model, ensemble=False, modelname=
     return lse
 
 
-def save_model(model, predictor, num=None, suffix=False):
+def save_model(model: tf.keras.Model, predictor: str, num: int = None, suffix: str = None):
     key = get_key(predictor, suffix)
     base_path = resource_filename(Requirement.parse("molSimplify"), "molSimplify/tf_nn/" + key)
     base_path = base_path + 'ensemble_models'
@@ -758,9 +762,9 @@ def save_model(model, predictor, num=None, suffix=False):
     print(("Saved model !%s! to disk" % name.split('/')[-1]))
 
 
-def initialize_model_weights(model):
+def initialize_model_weights(model: tf.keras.Model) -> tf.keras.Model:
     session = K.get_session()
-    for layer in model.layers: 
+    for layer in model.layers:
         for v in layer.__dict__:
             v_arg = getattr(layer, v)
             if hasattr(v_arg, 'initializer'):
